@@ -19,24 +19,26 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 ###############################################################################
 
-from __future__ import division
-import sys
-import string
-import re
+from collections import defaultdict
+import codecs
+import csv
+import io
+import math
 import os
 import os.path
+import re
+import string
+import sys
 import threading
-import codecs
-import io
-import csv
 import time
-from collections import defaultdict
 
-from ..compat import citems, cstr, CStringIO, cbasestr, cpy3, cbytes, crepr, \
-    crange
-from .. import qtall as qt
 import numpy as N
 
+from .. import qtall as qt
+
+DEG2RAD = math.pi/180
+RAD2DEG = 180/math.pi
+
 class IgnoreException(Exception):
     """A special exception class to be ignored by the exception handler."""
 
@@ -52,6 +54,9 @@ def _getVeuszDirectory():
     else:
         # standard installation
         resdir = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
+        if not os.path.exists(os.path.join(resdir, 'VERSION')):
+            # running from the current direction
+            resdir = os.path.join(resdir, '..')
 
     # override data directory with symlink
     if os.path.exists( os.path.join(resdir, 'resources') ):
@@ -71,12 +76,13 @@ resourceDirectory, exampleDirectory = _getVeuszDirectory()
 def getLicense():
     """Return license text."""
     try:
-        f = open(os.path.join(resourceDirectory, 'COPYING'), 'rU')
-        text = f.read()
-        f.close()
+        with open(os.path.join(resourceDirectory, 'COPYING')) as f:
+            text = f.read()
     except EnvironmentError:
-        text = ('Could not open the license file.\n'
-                'See license at http://www.gnu.org/licenses/gpl-2.0.html')
+        text = (
+            'Could not open the license file.\n'
+            'See license at http://www.gnu.org/licenses/gpl-2.0.html'
+        )
     return text
 
 id_re = re.compile('^[A-Za-z_][A-Za-z0-9_]*$')
@@ -142,7 +148,7 @@ def pixmapAsHtml(pix):
     buf = qt.QBuffer(ba)
     buf.open(qt.QIODevice.WriteOnly)
     pix.toImage().save(buf, "PNG")
-    b64 = cbytes(buf.data().toBase64()).decode('ascii')
+    b64 = bytes(buf.data().toBase64()).decode('ascii')
     return '<img src="data:image/png;base64,%s">' % b64
 
 def pythonise(text):
@@ -313,7 +319,7 @@ encodings = [
     'ptcp154', 'shift_jis_2004', 'shift_jis', 'shift_jisx0213',
     'tis_620','utf_16_be', 'utf_16_le', 'utf_16',
     'utf_32_be', 'utf_32_le', 'utf_32', 'utf_7', 'utf_8', 'utf_8_sig'
-    ]
+]
 
 def openEncoding(filename, encoding, mode='r'):
     """Convenience function for opening file with encoding given.
@@ -323,7 +329,7 @@ def openEncoding(filename, encoding, mode='r'):
     """
     if filename == '{clipboard}':
         text = qt.QApplication.clipboard().text()
-        return CStringIO(text)
+        return io.StringIO(text)
     else:
         return io.open(filename, mode, encoding=encoding, errors='ignore')
 
@@ -354,31 +360,21 @@ class _UTF8Decoder:
         return self
     def next(self):
         line = self.iterator.next()
-        return [cstr(x, "utf-8") for x in line]
+        return [str(x, "utf-8") for x in line]
 
 def get_unicode_csv_reader(filename, dialect=csv.excel,
                            encoding='utf-8', **kwds):
     """Return an iterator to iterate over CSV file with encoding given."""
 
     if filename != '{clipboard}':
-        if cpy3:
-            # python3 native encoding support
-            f = open(filename, encoding=encoding, errors='ignore')
-        else:
-            # recode the opened file as utf-8
-            f = _UTF8Recoder(open(filename), encoding)
+        f = open(filename, encoding=encoding, errors='ignore')
     else:
         # take the unicode clipboard and just put into utf-8 format
         s = qt.QApplication.clipboard().text()
-        if not cpy3:
-            s = s.encode("utf-8")
-        f = CStringIO(s)
+        f = io.StringIO(s)
 
     reader = csv.reader(f, dialect=dialect, **kwds)
-    if cpy3:
-        return reader
-    else:
-        return _UTF8Decoder(reader)
+    return reader
 
 # End python doc classes
 
@@ -464,12 +460,12 @@ def topological_sort(dependency_pairs):
             if not num_heads[t]:
                 ordered.append(t)
         i += 1
-    cyclic = [n for n, heads in citems(num_heads) if heads]
+    cyclic = [n for n, heads in num_heads.items() if heads]
     return ordered, cyclic
 
 def isiternostr(i):
     """Is this iterator, but not a string?"""
-    return hasattr(i, '__iter__') and not isinstance(i, cbasestr)
+    return hasattr(i, '__iter__') and not isinstance(i, str)
 
 def nextfloat(fin):
     """Return (approximately) next float value (for f>0)."""
@@ -499,7 +495,7 @@ def round2delt(fin1, fin2):
     else:
         out1 = out2 = ''
 
-    for i in crange(maxlog,-200,-1):
+    for i in range(maxlog,-200,-1):
         p = 10**i
         d1, d2 = int(f1/p), int(f2/p)
         f1 -= int(d1)*p
@@ -564,7 +560,7 @@ def rrepr(val):
         l = [rrepr(v) for v in val]
         return "[%s]" % ", ".join(l)
     else:
-        return crepr(val)
+        return repr(val)
 
 def escapeHDFDataName(name):
     """Return escaped dataset name for saving in HDF5 files.
@@ -599,6 +595,13 @@ def findOnPath(cmd):
             return cmdtry
     return None
 
+def listIndex(inlist, item):
+    """Return index of item in list or -1 if not available."""
+    try:
+        return inlist.index(item)
+    except ValueError:
+        return -1
+
 class Struct:
     """Simple structure-like class."""
 
@@ -607,8 +610,11 @@ class Struct:
 
     def __repr__(self):
         return '<%s>' % str(
-            ', '.join('%s:%s' % (k, repr(getattr(self, k)))
-                       for k in sorted(self.__dict__)))
+            ', '.join(
+                '%s:%s' % (k, repr(getattr(self, k)))
+                for k in sorted(self.__dict__)
+            )
+        )
 
 class SvgWidgetFixedAspect(qt.QWidget):
     """Draw an SVG file with the aspect ratio fixed to the original."""
@@ -654,3 +660,28 @@ class OverrideCursor:
 
     def __exit__(self, typ, value, traceback):
         qt.QApplication.restoreOverrideCursor()
+
+class DisabledIconEngine(qt.QIconEngine):
+    """Icon engine which draws icons in a disabled state."""
+
+    def __init__(self, icon):
+        qt.QIconEngine.__init__(self)
+        self.icon = icon
+
+    def actualSize(self, size, mode, state):
+        return size
+
+    def clone(self):
+        return GreyIconEngine(self.icon)
+
+    def iconName(self):
+        return ''
+
+    def key(self):
+        return str(id(self))
+
+    def paint(self, painter, rect, mode, state):
+        self.icon.paint(painter, rect, qt.Qt.AlignCenter, qt.QIcon.Disabled, state)
+
+    def pixmap(self, size, mode, state):
+        return self.icon.pixmap(size, qt.QIcon.Disabled, state)
